@@ -6,11 +6,11 @@ Dancer::Plugin::PageHistory - store recent page history for user into session
 
 =head1 VERSION
 
-Version 0.101
+Version 0.102
 
 =cut
 
-our $VERSION = '0.101';
+our $VERSION = '0.102';
 
 use Dancer ':syntax';
 use Dancer::Plugin;
@@ -76,7 +76,7 @@ L<Dancer::Session::Cookie> and L<Dancer::Session::PSGI> either don't handle
 destroy at all or else do it wrong so I suggest you avoid those modules if
 you want things like logout to work.
 
-See </TODO>.
+See L</TODO>.
 
 =head1 CONFIGURATION
 
@@ -230,8 +230,6 @@ Peter Mottram (SysPete), "peter@sysnix.com"
 
 =head1 BUGS
 
-This is BETA software so bugs and missing features are expected.
-
 Please report any bugs or feature requests via the project's GitHub
 issue tracker:
 
